@@ -25,12 +25,12 @@ template<typename eT>
 inline
 MapMat<eT>::~MapMat()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   if(map_ptr)  { (*map_ptr).clear();  delete map_ptr; }
   
   // try to expose buggy user code that accesses deleted objects
-  if(arma_config::debug)  { map_ptr = nullptr; }
+  map_ptr = nullptr;
   
   arma_type_check(( is_supported_elem_type<eT>::value == false ));
   }
@@ -45,7 +45,7 @@ MapMat<eT>::MapMat()
   , n_elem (0)
   , map_ptr(nullptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init_cold();
   }
@@ -60,7 +60,7 @@ MapMat<eT>::MapMat(const uword in_n_rows, const uword in_n_cols)
   , n_elem (in_n_rows * in_n_cols)
   , map_ptr(nullptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init_cold();
   }
@@ -75,7 +75,7 @@ MapMat<eT>::MapMat(const SizeMat& s)
   , n_elem (s.n_rows * s.n_cols)
   , map_ptr(nullptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init_cold();
   }
@@ -90,7 +90,7 @@ MapMat<eT>::MapMat(const MapMat<eT>& x)
   , n_elem (0)
   , map_ptr(nullptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init_cold();
   
@@ -104,7 +104,7 @@ inline
 void
 MapMat<eT>::operator=(const MapMat<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(this == &x)  { return; }
   
@@ -125,7 +125,7 @@ MapMat<eT>::MapMat(const SpMat<eT>& x)
   , n_elem (0)
   , map_ptr(nullptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init_cold();
   
@@ -139,7 +139,7 @@ inline
 void
 MapMat<eT>::operator=(const SpMat<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword x_n_rows = x.n_rows;
   const uword x_n_cols = x.n_cols;
@@ -181,7 +181,7 @@ MapMat<eT>::MapMat(MapMat<eT>&& x)
   , n_elem (x.n_elem )
   , map_ptr(x.map_ptr)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   access::rw(x.n_rows)  = 0;
   access::rw(x.n_cols)  = 0;
@@ -196,7 +196,7 @@ inline
 void
 MapMat<eT>::operator=(MapMat<eT>&& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(this == &x)  { return; }
   
@@ -222,7 +222,7 @@ inline
 void
 MapMat<eT>::reset()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(n_rows) = 0;
   access::rw(n_cols) = 0;
@@ -238,7 +238,7 @@ inline
 void
 MapMat<eT>::set_size(const uword in_n_rows)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(in_n_rows, 1);
   }
@@ -250,7 +250,7 @@ inline
 void
 MapMat<eT>::set_size(const uword in_n_rows, const uword in_n_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(in_n_rows, in_n_cols);
   }
@@ -262,7 +262,7 @@ inline
 void
 MapMat<eT>::set_size(const SizeMat& s)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(s.n_rows, s.n_cols);
   }
@@ -274,7 +274,7 @@ inline
 void
 MapMat<eT>::zeros()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*map_ptr).clear();
   }
@@ -286,7 +286,7 @@ inline
 void
 MapMat<eT>::zeros(const uword in_n_rows)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(in_n_rows, 1);
   
@@ -300,7 +300,7 @@ inline
 void
 MapMat<eT>::zeros(const uword in_n_rows, const uword in_n_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(in_n_rows, in_n_cols);
   
@@ -314,7 +314,7 @@ inline
 void
 MapMat<eT>::zeros(const SizeMat& s)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init_warm(s.n_rows, s.n_cols);
   
@@ -328,7 +328,7 @@ inline
 void
 MapMat<eT>::eye()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).eye(n_rows, n_cols);
   }
@@ -340,7 +340,7 @@ inline
 void
 MapMat<eT>::eye(const uword in_n_rows, const uword in_n_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   zeros(in_n_rows, in_n_cols);
   
@@ -363,7 +363,7 @@ inline
 void
 MapMat<eT>::eye(const SizeMat& s)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).eye(s.n_rows, s.n_cols);
   }
@@ -375,7 +375,7 @@ inline
 void
 MapMat<eT>::speye()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).eye();
   }
@@ -387,7 +387,7 @@ inline
 void
 MapMat<eT>::speye(const uword in_n_rows, const uword in_n_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).eye(in_n_rows, in_n_cols);
   }
@@ -399,7 +399,7 @@ inline
 void
 MapMat<eT>::speye(const SizeMat& s)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).eye(s);
   }
@@ -408,7 +408,6 @@ MapMat<eT>::speye(const SizeMat& s)
 
 template<typename eT>
 arma_inline
-arma_warn_unused
 MapMat_val<eT>
 MapMat<eT>::operator[](const uword index)
   {
@@ -419,7 +418,6 @@ MapMat<eT>::operator[](const uword index)
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 MapMat<eT>::operator[](const uword index) const
   {
@@ -435,11 +433,10 @@ MapMat<eT>::operator[](const uword index) const
 
 template<typename eT>
 arma_inline
-arma_warn_unused
 MapMat_val<eT>
 MapMat<eT>::operator()(const uword index)
   {
-  arma_debug_check_bounds( (index >= n_elem), "MapMat::operator(): index out of bounds" );
+  arma_conform_check_bounds( (index >= n_elem), "MapMat::operator(): index out of bounds" );
   
   return MapMat_val<eT>(*this, index);
   }
@@ -448,11 +445,10 @@ MapMat<eT>::operator()(const uword index)
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 MapMat<eT>::operator()(const uword index) const
   {
-  arma_debug_check_bounds( (index >= n_elem), "MapMat::operator(): index out of bounds" );
+  arma_conform_check_bounds( (index >= n_elem), "MapMat::operator(): index out of bounds" );
   
   map_type& map_ref = (*map_ptr);
   
@@ -466,7 +462,6 @@ MapMat<eT>::operator()(const uword index) const
 
 template<typename eT>
 arma_inline
-arma_warn_unused
 MapMat_val<eT>
 MapMat<eT>::at(const uword in_row, const uword in_col)
   {
@@ -479,7 +474,6 @@ MapMat<eT>::at(const uword in_row, const uword in_col)
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 MapMat<eT>::at(const uword in_row, const uword in_col) const
   {
@@ -497,11 +491,10 @@ MapMat<eT>::at(const uword in_row, const uword in_col) const
 
 template<typename eT>
 arma_inline
-arma_warn_unused
 MapMat_val<eT>
 MapMat<eT>::operator()(const uword in_row, const uword in_col)
   {
-  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols)), "MapMat::operator(): index out of bounds" );
+  arma_conform_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols)), "MapMat::operator(): index out of bounds" );
   
   const uword index = (n_rows * in_col) + in_row;
   
@@ -512,11 +505,10 @@ MapMat<eT>::operator()(const uword in_row, const uword in_col)
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 MapMat<eT>::operator()(const uword in_row, const uword in_col) const
   {
-  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols)), "MapMat::operator(): index out of bounds" );
+  arma_conform_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols)), "MapMat::operator(): index out of bounds" );
   
   const uword index = (n_rows * in_col) + in_row;
   
@@ -532,7 +524,6 @@ MapMat<eT>::operator()(const uword in_row, const uword in_col) const
 
 template<typename eT>
 inline
-arma_warn_unused
 bool
 MapMat<eT>::is_empty() const
   {
@@ -543,7 +534,6 @@ MapMat<eT>::is_empty() const
 
 template<typename eT>
 inline
-arma_warn_unused
 bool
 MapMat<eT>::is_vec() const
   {
@@ -554,7 +544,6 @@ MapMat<eT>::is_vec() const
 
 template<typename eT>
 inline
-arma_warn_unused
 bool
 MapMat<eT>::is_rowvec() const
   {
@@ -566,7 +555,6 @@ MapMat<eT>::is_rowvec() const
 //! returns true if the object can be interpreted as a column vector
 template<typename eT>
 inline
-arma_warn_unused
 bool
 MapMat<eT>::is_colvec() const
   {
@@ -577,7 +565,6 @@ MapMat<eT>::is_colvec() const
 
 template<typename eT>
 inline
-arma_warn_unused
 bool
 MapMat<eT>::is_square() const
   {
@@ -592,7 +579,7 @@ inline
 void
 MapMat<eT>::sprandu(const uword in_n_rows, const uword in_n_cols, const double density)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   zeros(in_n_rows, in_n_cols);
   
@@ -623,7 +610,7 @@ inline
 void
 MapMat<eT>::print(const std::string& extra_text) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(extra_text.length() != 0)
     {
@@ -675,7 +662,7 @@ inline
 uword
 MapMat<eT>::get_n_nonzero() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return uword((*map_ptr).size());
   }
@@ -687,7 +674,7 @@ inline
 void
 MapMat<eT>::get_locval_format(umat& locs, Col<eT>& vals) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   map_type& map_ref = (*map_ptr);
   
@@ -728,7 +715,7 @@ inline
 void
 MapMat<eT>::init_cold()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   // ensure that n_elem can hold the result of (n_rows * n_cols)
   
@@ -738,7 +725,7 @@ MapMat<eT>::init_cold()
     const char* error_message = "MapMat(): requested size is too large; suggest to enable ARMA_64BIT_WORD";
   #endif
   
-  arma_debug_check
+  arma_conform_check
     (
       (
       ( (n_rows > ARMA_MAX_UHWORD) || (n_cols > ARMA_MAX_UHWORD) )
@@ -760,7 +747,7 @@ inline
 void
 MapMat<eT>::init_warm(const uword in_n_rows, const uword in_n_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if( (n_rows == in_n_rows) && (n_cols == in_n_cols))  { return; }
   
@@ -772,7 +759,7 @@ MapMat<eT>::init_warm(const uword in_n_rows, const uword in_n_cols)
     const char* error_message = "MapMat(): requested size is too large; suggest to enable ARMA_64BIT_WORD";
   #endif
   
-  arma_debug_check
+  arma_conform_check
     (
       (
       ( (in_n_rows > ARMA_MAX_UHWORD) || (in_n_cols > ARMA_MAX_UHWORD) )
@@ -798,7 +785,7 @@ arma_inline
 void
 MapMat<eT>::set_val(const uword index, const eT& in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(in_val != eT(0))
     {
@@ -826,7 +813,7 @@ inline
 void
 MapMat<eT>::erase_val(const uword index)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   map_type& map_ref = (*map_ptr);
   
@@ -851,7 +838,7 @@ MapMat_val<eT>::MapMat_val(MapMat<eT>& in_parent, const uword in_index)
   : parent(in_parent)
   , index (in_index )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -860,7 +847,7 @@ template<typename eT>
 arma_inline
 MapMat_val<eT>::operator eT() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const MapMat<eT>& const_parent = parent;
   
@@ -874,7 +861,7 @@ arma_inline
 typename get_pod_type<eT>::result
 MapMat_val<eT>::real() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename get_pod_type<eT>::result T;
   
@@ -890,7 +877,7 @@ arma_inline
 typename get_pod_type<eT>::result
 MapMat_val<eT>::imag() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename get_pod_type<eT>::result T;
   
@@ -906,7 +893,7 @@ arma_inline
 void
 MapMat_val<eT>::operator=(const MapMat_val<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT in_val = eT(x);
   
@@ -920,7 +907,7 @@ arma_inline
 void
 MapMat_val<eT>::operator=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   parent.set_val(index, in_val);
   }
@@ -932,7 +919,7 @@ arma_inline
 void
 MapMat_val<eT>::operator+=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -953,7 +940,7 @@ arma_inline
 void
 MapMat_val<eT>::operator-=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -974,7 +961,7 @@ arma_inline
 void
 MapMat_val<eT>::operator*=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -1005,7 +992,7 @@ arma_inline
 void
 MapMat_val<eT>::operator/=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -1037,7 +1024,7 @@ arma_inline
 void
 MapMat_val<eT>::operator++()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -1055,7 +1042,7 @@ arma_inline
 void
 MapMat_val<eT>::operator++(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator++();
   }
@@ -1067,7 +1054,7 @@ arma_inline
 void
 MapMat_val<eT>::operator--()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typename MapMat<eT>::map_type& map_ref = *(parent.map_ptr);
   
@@ -1085,7 +1072,7 @@ arma_inline
 void
 MapMat_val<eT>::operator--(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator--();
   }
@@ -1106,7 +1093,7 @@ SpMat_MapMat_val<eT>::SpMat_MapMat_val(SpMat<eT>& in_s_parent, MapMat<eT>& in_m_
   , row     (in_row     )
   , col     (in_col     )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -1115,7 +1102,7 @@ template<typename eT>
 inline
 SpMat_MapMat_val<eT>::operator eT() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const SpMat<eT>& const_s_parent = s_parent;  // declare as const for clarity of intent
   
@@ -1129,7 +1116,7 @@ inline
 typename get_pod_type<eT>::result
 SpMat_MapMat_val<eT>::real() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename get_pod_type<eT>::result T;
   
@@ -1145,7 +1132,7 @@ inline
 typename get_pod_type<eT>::result
 SpMat_MapMat_val<eT>::imag() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename get_pod_type<eT>::result T;
   
@@ -1161,7 +1148,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator=(const SpMat_MapMat_val<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT in_val = eT(x);
   
@@ -1175,7 +1162,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_OPENMP)
     {
@@ -1184,7 +1171,7 @@ SpMat_MapMat_val<eT>::operator=(const eT in_val)
       (*this).set(in_val);
       }
     }
-  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
+  #elif defined(ARMA_USE_STD_MUTEX)
     {
     const std::lock_guard<std::mutex> lock(s_parent.cache_mutex);
     
@@ -1206,7 +1193,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator+=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(in_val == eT(0))  { return *this; }
   
@@ -1217,7 +1204,7 @@ SpMat_MapMat_val<eT>::operator+=(const eT in_val)
       (*this).add(in_val);
       }
     }
-  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
+  #elif defined(ARMA_USE_STD_MUTEX)
     {
     const std::lock_guard<std::mutex> lock(s_parent.cache_mutex);
     
@@ -1239,7 +1226,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator-=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(in_val == eT(0))  { return *this; }
   
@@ -1250,7 +1237,7 @@ SpMat_MapMat_val<eT>::operator-=(const eT in_val)
       (*this).sub(in_val);
       }
     }
-  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
+  #elif defined(ARMA_USE_STD_MUTEX)
     {
     const std::lock_guard<std::mutex> lock(s_parent.cache_mutex);
     
@@ -1272,7 +1259,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator*=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_OPENMP)
     {
@@ -1281,7 +1268,7 @@ SpMat_MapMat_val<eT>::operator*=(const eT in_val)
       (*this).mul(in_val);
       }
     }
-  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
+  #elif defined(ARMA_USE_STD_MUTEX)
     {
     const std::lock_guard<std::mutex> lock(s_parent.cache_mutex);
     
@@ -1303,7 +1290,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator/=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_OPENMP)
     {
@@ -1312,7 +1299,7 @@ SpMat_MapMat_val<eT>::operator/=(const eT in_val)
       (*this).div(in_val);
       }
     }
-  #elif (!defined(ARMA_DONT_USE_STD_MUTEX))
+  #elif defined(ARMA_USE_STD_MUTEX)
     {
     const std::lock_guard<std::mutex> lock(s_parent.cache_mutex);
     
@@ -1334,7 +1321,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator++()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return (*this).operator+=( eT(1) );
   }
@@ -1343,11 +1330,10 @@ SpMat_MapMat_val<eT>::operator++()
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 SpMat_MapMat_val<eT>::operator++(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT old_val = eT(*this);
   
@@ -1363,7 +1349,7 @@ inline
 SpMat_MapMat_val<eT>&
 SpMat_MapMat_val<eT>::operator--()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return (*this).operator-=( eT(1) );
   }
@@ -1372,11 +1358,10 @@ SpMat_MapMat_val<eT>::operator--()
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 SpMat_MapMat_val<eT>::operator--(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT old_val = eT(*this);
   
@@ -1392,7 +1377,7 @@ inline
 void
 SpMat_MapMat_val<eT>::set(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool done = (s_parent.sync_state == 0) ? s_parent.try_set_value_csc(row, col, in_val) : false;
   
@@ -1417,7 +1402,7 @@ inline
 void
 SpMat_MapMat_val<eT>::add(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool done = (s_parent.sync_state == 0) ? s_parent.try_add_value_csc(row, col, in_val) : false;
     
@@ -1448,7 +1433,7 @@ inline
 void
 SpMat_MapMat_val<eT>::sub(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool done = (s_parent.sync_state == 0) ? s_parent.try_sub_value_csc(row, col, in_val) : false;
   
@@ -1479,7 +1464,7 @@ inline
 void
 SpMat_MapMat_val<eT>::mul(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool done = (s_parent.sync_state == 0) ? s_parent.try_mul_value_csc(row, col, in_val) : false;
   
@@ -1540,7 +1525,7 @@ inline
 void
 SpMat_MapMat_val<eT>::div(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool done = (s_parent.sync_state == 0) ? s_parent.try_div_value_csc(row, col, in_val) : false;
   
@@ -1600,7 +1585,7 @@ SpSubview_MapMat_val<eT>::SpSubview_MapMat_val(SpSubview<eT>& in_sv_parent, MapM
   : SpMat_MapMat_val<eT>(access::rw(in_sv_parent.m), in_m_parent, in_row, in_col)
   , sv_parent(in_sv_parent)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -1610,7 +1595,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator=(const SpSubview_MapMat_val<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT in_val = eT(x);
   
@@ -1624,7 +1609,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1643,7 +1628,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator+=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1662,7 +1647,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator-=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1681,7 +1666,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator*=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1700,7 +1685,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator/=(const eT in_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1719,7 +1704,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator++()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1735,11 +1720,10 @@ SpSubview_MapMat_val<eT>::operator++()
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 SpSubview_MapMat_val<eT>::operator++(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1758,7 +1742,7 @@ inline
 SpSubview_MapMat_val<eT>&
 SpSubview_MapMat_val<eT>::operator--()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
@@ -1774,11 +1758,10 @@ SpSubview_MapMat_val<eT>::operator--()
 
 template<typename eT>
 inline
-arma_warn_unused
 eT
 SpSubview_MapMat_val<eT>::operator--(int)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword old_n_nonzero = sv_parent.m.n_nonzero;
   
