@@ -275,31 +275,31 @@ Rcpp::List nuggetkriging_model(Rcpp::List k) {
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
-  Rcpp::List ret = Rcpp::List::create(Rcpp::Named("kernel") = impl_ptr->kernel(),
-                                      Rcpp::Named("optim") = impl_ptr->optim(),
-                                      Rcpp::Named("objective") = impl_ptr->objective(),
-                                      Rcpp::Named("theta") = impl_ptr->theta(),
-                                      Rcpp::Named("is_theta_estim") = impl_ptr->is_theta_estim(),
-                                      Rcpp::Named("sigma2") = impl_ptr->sigma2(),
-                                      Rcpp::Named("is_sigma2_estim") = impl_ptr->is_sigma2_estim(),
-                                      Rcpp::Named("nugget") = impl_ptr->nugget(),
-                                      Rcpp::Named("is_nugget_estim") = impl_ptr->is_nugget_estim(),
-                                      Rcpp::Named("X") = impl_ptr->X(),
-                                      Rcpp::Named("centerX") = impl_ptr->centerX(),
-                                      Rcpp::Named("scaleX") = impl_ptr->scaleX(),
-                                      Rcpp::Named("y") = impl_ptr->y(),
-                                      Rcpp::Named("centerY") = impl_ptr->centerY(),
-                                      Rcpp::Named("scaleY") = impl_ptr->scaleY(),
-                                      Rcpp::Named("normalize") = impl_ptr->normalize(),
-                                      Rcpp::Named("regmodel") = Trend::toString(impl_ptr->regmodel()),
-                                      Rcpp::Named("beta") = impl_ptr->beta(),
-                                      Rcpp::Named("is_beta_estim") = impl_ptr->is_beta_estim());
+  Rcpp::List ret = Rcpp::List(22);
 
-  // because Rcpp::List::create accepts no more than 20 args...
-  ret.push_back(impl_ptr->F(), "F");
-  ret.push_back(impl_ptr->T(), "T");
-  ret.push_back(impl_ptr->M(), "M");
-  ret.push_back(impl_ptr->z(), "z");
+  ret["kernel"] = impl_ptr->kernel();
+  ret["optim"] = impl_ptr->optim();
+  ret["objective"] = impl_ptr->objective();
+  ret["theta"] = impl_ptr->theta();
+  ret["is_theta_estim"] = impl_ptr->is_theta_estim();
+  ret["sigma2"] = impl_ptr->sigma2();
+  ret["is_sigma2_estim"] = impl_ptr->is_sigma2_estim();
+  ret["nugget"] = impl_ptr->nugget();
+  ret["is_nugget_estim"] = impl_ptr->is_nugget_estim();
+  ret["X"] = impl_ptr->X();
+  ret["centerX"] = impl_ptr->centerX();
+  ret["scaleX"] = impl_ptr->scaleX();
+  ret["y"] = impl_ptr->y();
+  ret["centerY"] = impl_ptr->centerY();
+  ret["scaleY"] = impl_ptr->scaleY();
+  ret["normalize"] = impl_ptr->normalize();
+  ret["regmodel"] = Trend::toString(impl_ptr->regmodel());
+  ret["beta"] = impl_ptr->beta();
+  ret["is_beta_estim"] = impl_ptr->is_beta_estim();
+  ret["F"] = impl_ptr->F();
+  ret["T"] = impl_ptr->T();
+  ret["M"] = impl_ptr->M();
+  ret["z"] = impl_ptr->z();
 
   return ret;
 }
@@ -327,6 +327,10 @@ Rcpp::List nuggetkriging_predict(Rcpp::List k,
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  int d = impl_ptr->X().n_cols;
+  if (d != X_n.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+
   auto pred = impl_ptr->predict(X_n, return_stdev, return_cov, return_deriv);
 
   Rcpp::List ret = Rcpp::List::create(Rcpp::Named("mean") = std::get<0>(pred));
@@ -357,6 +361,10 @@ arma::mat nuggetkriging_simulate(Rcpp::List k,
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  int d = impl_ptr->X().n_cols;
+  if (d != X_n.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+
   return impl_ptr->simulate(nsim, seed, X_n, with_nugget, will_update);
 }
 
@@ -368,6 +376,13 @@ arma::mat nuggetkriging_update_simulate(Rcpp::List k, arma::vec y_u, arma::mat X
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  int d = impl_ptr->X().n_cols;
+  if (d != X_u.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+
+  if (X_u.n_rows != y_u.n_elem)
+    Rcpp::stop("Length of arg data should be the same.");
+
   return impl_ptr->update_simulate(y_u, X_u);
 }
 
@@ -379,6 +394,13 @@ void nuggetkriging_update(Rcpp::List k, arma::vec y_u, arma::mat X_u, bool refit
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  int d = impl_ptr->X().n_cols;
+  if (d != X_u.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+
+  if (X_u.n_rows != y_u.n_elem)
+    Rcpp::stop("Length of arg data should be the same.");
+
   impl_ptr->update(y_u, X_u, refit);
 
   // Rcpp::List obj;
@@ -406,6 +428,12 @@ arma::mat nuggetkriging_covMat(Rcpp::List k, arma::mat X1, arma::mat X2) {
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  int d = impl_ptr->X().n_cols;
+  if (d != X1.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+  if (d != X2.n_cols)
+    Rcpp::stop("Dimension of arg data should be " + std::to_string(d) + ")");
+
   return impl_ptr->covMat(X1, X2);
 }
 
@@ -420,6 +448,9 @@ Rcpp::List nuggetkriging_logLikelihoodFun(Rcpp::List k,
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
+  if (theta_alpha.n_elem != impl_ptr->theta().n_elem + 1)
+    Rcpp::stop("Length of arg data should be " + std::to_string(impl_ptr->theta().n_elem + 1) + ")");
+
   std::tuple<double, arma::vec> ll = impl_ptr->logLikelihoodFun(theta_alpha, return_grad, bench);
 
   Rcpp::List ret = Rcpp::List::create(Rcpp::Named("logLikelihood") = std::get<0>(ll));
@@ -442,14 +473,20 @@ double nuggetkriging_logLikelihood(Rcpp::List k) {
 }
 
 // [[Rcpp::export]]
-Rcpp::List nuggetkriging_logMargPostFun(Rcpp::List k, arma::vec theta, bool return_grad = false, bool bench = false) {
+Rcpp::List nuggetkriging_logMargPostFun(Rcpp::List k,
+                                        arma::vec theta_alpha,
+                                        bool return_grad = false,
+                                        bool bench = false) {
   if (!k.inherits("NuggetKriging"))
     Rcpp::stop("Input must be a NuggetKriging object.");
   SEXP impl = k.attr("object");
 
   Rcpp::XPtr<NuggetKriging> impl_ptr(impl);
 
-  std::tuple<double, arma::vec> lmp = impl_ptr->logMargPostFun(theta, return_grad, bench);
+  if (theta_alpha.n_elem != impl_ptr->theta().n_elem + 1)
+    Rcpp::stop("Length of arg data should be " + std::to_string(impl_ptr->theta().n_elem + 1) + ")");
+
+  std::tuple<double, arma::vec> lmp = impl_ptr->logMargPostFun(theta_alpha, return_grad, bench);
 
   Rcpp::List ret = Rcpp::List::create(Rcpp::Named("logMargPost") = std::get<0>(lmp));
   if (return_grad) {
