@@ -1,5 +1,5 @@
 extern "C" {
-void setulb_(const int* n,
+int setulb_(const int* n,
              const int* m,
              double* x,
              const double* l,
